summaryrefslogtreecommitdiffstats
path: root/src/H5VMprivate.h
diff options
context:
space:
mode:
authorDana Robinson <derobins@hdfgroup.org>2020-08-14 13:32:58 (GMT)
committerDana Robinson <derobins@hdfgroup.org>2020-08-14 13:32:58 (GMT)
commit3feeb8ec20a7b08acdcd77f3e10c8c93818d890e (patch)
tree02cb6175cb0eb1a5ba6ee9f9014d49aa7380c059 /src/H5VMprivate.h
parent6b347a8d97d225ac1ed951c7954afa1dd14aaecb (diff)
downloadhdf5-3feeb8ec20a7b08acdcd77f3e10c8c93818d890e.zip
hdf5-3feeb8ec20a7b08acdcd77f3e10c8c93818d890e.tar.gz
hdf5-3feeb8ec20a7b08acdcd77f3e10c8c93818d890e.tar.bz2
Fixes naming issues in H5VM inline functions
Diffstat (limited to 'src/H5VMprivate.h')
-rw-r--r--src/H5VMprivate.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/H5VMprivate.h b/src/H5VMprivate.h
index e784847..5c975f6 100644
--- a/src/H5VMprivate.h
+++ b/src/H5VMprivate.h
@@ -164,8 +164,8 @@ H5VM_vector_reduce_product(unsigned n, const hsize_t *v)
{
hsize_t ret_value = 1;
- /* Use FUNC_ENTER_STATIC_NOERR here to avoid performance issues */
- FUNC_ENTER_STATIC_NOERR
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (n && !v) HGOTO_DONE(0)
while (n--) ret_value *= *v++;
@@ -198,8 +198,8 @@ H5VM_vector_zerop_u(int n, const hsize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_STATIC_NOERR here to avoid performance issues */
- FUNC_ENTER_STATIC_NOERR
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (!v)
HGOTO_DONE(TRUE)
@@ -235,8 +235,8 @@ H5VM_vector_zerop_s(int n, const hssize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_STATIC_NOERR here to avoid performance issues */
- FUNC_ENTER_STATIC_NOERR
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (!v)
HGOTO_DONE(TRUE)
@@ -274,8 +274,8 @@ H5VM_vector_cmp_u(unsigned n, const hsize_t *v1, const hsize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_STATIC_NOERR here to avoid performance issues */
- FUNC_ENTER_STATIC_NOERR
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (v1 == v2) HGOTO_DONE(0)
if (v1 == NULL) HGOTO_DONE(-1)
@@ -318,8 +318,8 @@ H5VM_vector_cmp_s(unsigned n, const hssize_t *v1, const hssize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_STATIC_NOERR here to avoid performance issues */
- FUNC_ENTER_STATIC_NOERR
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
if (v1 == v2) HGOTO_DONE(0)
if (v1 == NULL) HGOTO_DONE(-1)